c2cgeoportal application
========================

c2cgeoportal is the server part of `GeoMapFish`,
the old client part is `CGXP <https://github.com/camptocamp/cgxp/>`_,
the new client part is `ngeo <https://github.com/camptocamp/ngeo/>`_.

Read the `Documentation <https://camptocamp.github.io/c2cgeoportal/>`_.
